
define([
    'services/services',
    'controllers/controllers',
  ],

  function () {
    'use strict';
// Ionic Starter App
    var app = angular.module('starter', ['ionic', 'ngCordova', 'starter.controllers','starter.services','pascalprecht.translate'])
    app.run(function($ionicPlatform) {
      $ionicPlatform.ready(function() {

        if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
          cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
          cordova.plugins.Keyboard.disableScroll(true);
        }
        if (window.StatusBar) {
          StatusBar.styleDefault();
        }

      });

    })
      .constant('$ionicLoadingConfig', {
        //template: '<img src="img/loginAndRegister/LOGO.gif" style="border:none;width:50px;height:50px;">',//动画模板
        template: '<ion-spinner icon="ios" style="border:none;width: 100px;height: 100px;"></ion-spinner>',
        hideOnStateChange:true,
        animation:'fade-in-out',
        showBackdrop: false,                 //是否显示蒙层
        maxWidth: 600,
        showDelay: 0,
        duration:10000,
      })
      .config(function ($ionicConfigProvider,$sceDelegateProvider,$stateProvider, $urlRouterProvider, $controllerProvider,$translateProvider,$httpProvider) {
        $ionicConfigProvider.tabs.position('bottom'); // 其他为：top
        $ionicConfigProvider.platform.android.views.maxCache(5); // 安卓要缓存5个view iOS默认为10个
        $ionicConfigProvider.tabs.style('standard');
        $sceDelegateProvider.resourceUrlWhitelist([
          // 用于装载可信任的AngularJs资源（如template）的白名单和黑名单
          'self',
          // Allow loading from our assets domain.  Notice the difference between * and **
          'http://srv*.assets.examplate.com/**'
        ]);

          app.registerController = $controllerProvider.register;
        app.loadControllerJs = function (controllerJs) {
          return function ($rootScope, $q) {
            var def = $q.defer(), deps = [];
            angular.isArray(controllerJs) ? (deps = controllerJs) : deps.push(controllerJs);
            require(deps, function () {
              $rootScope.$apply(function () {
                def.resolve();
              });
            });
            return def.promise;
          };
        }

        // 国际化
        var lang = "" || "zh";
        //$translateProvider.preferredLanguage(lang);
        $translateProvider.useStaticFilesLoader({
          prefix: 'languages/',
          suffix: '.json'
        });

        // if none of the above states are matched, use this as the fallback
        var templateName = myObj.willShowTemplateName();
        //var templateName = 'personal';
        $urlRouterProvider.otherwise(templateName);

        // Ionic uses AngularUI Router which uses the concept of states
        $stateProvider

          //*************************************** 登录注册***************************************//
          // 登录
          .state('login', {
            url: '/login',
            templateUrl: 'templates/loginAndRegister/login.html',
            controller: 'loginCtrl',
            resolve : {
              //这里要执行加载js，我们使用$q的方法阻塞执行
              //定义了一个方法，这个方法接受一个路径名称或者包含路径名称的数组
              //使用$q的方式异步执行
              //这里的话应该是这么理解的，使用require的方式加载文件，通过require的相应callback
              //响应了$q的执行结果事件resolve
              deps: app.loadControllerJs('./controllers/loginAndRegister/login')
            }
          })
          // 找回密码
          .state('findpsw', {
            url: '/findpsw/:params',
            templateUrl: 'templates/loginAndRegister/findpsw.html',
            controller: 'findpswCtrl',
            resolve : {
              deps: app.loadControllerJs('./controllers/loginAndRegister/findpsw')
            }
          })
          // 注册
          .state('register', {
            url: '/register',
            templateUrl: 'templates/loginAndRegister/register.html',
            controller: 'registerCtrl',
            resolve : {
              deps: app.loadControllerJs('./controllers/loginAndRegister/register')
            }
          })
          //*************************************** 好友***************************************//
          .state('friend', {
            url: '/friend',
            templateUrl: 'templates/friend/friend.html',
            controller: 'friendCtrl',
            resolve : {
              deps: app.loadControllerJs('./controllers/friend/friend')
            }
          })
          .state('sharecamera', {
            url: '/sharecamera/:params',
            templateUrl: 'templates/friend/share-camera.html',
            controller: 'shareCameraCtrl',
            resolve : {
              deps: app.loadControllerJs('./controllers/friend/share-camera')
            }
          })
          //********************************** 云存储支付********************************//
          .state('cloud', {
            url: '/cloud',
            templateUrl: 'templates/pay/cloud-info.html',
            controller: 'cloudInfoCtrl',
            resolve : {
              deps: app.loadControllerJs('./controllers/pay/cloud-info')
            }
          })
          .state('cloudPay', {
            url: '/pay/:params',
            cache: false,
            templateUrl: 'templates/pay/cloud-pay.html',
            controller: 'cloudPayCtrl',
            resolve : {
              deps: app.loadControllerJs('./controllers/pay/cloud-pay')
            }
          })
          .state('cloudOrder', {
            url: '/order',
            cache: false,
            templateUrl: 'templates/pay/cloud-order.html',
            controller: 'orderCtrl',
            resolve : {
              deps: app.loadControllerJs('./controllers/pay/cloud-order')
            }
          })

        //********************************** 更多********************************//
          .state('more', {
            url:'/more',
            templateUrl: 'templates/more/more-home.html',
            controller: 'moreHomeCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/more/more-home')
            }
          })
          .state('morePicVideo', {
            url:'/picvideo',
            templateUrl: 'templates/more/more-picVideo.html',
            controller: 'morePicVideoCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/more/more-picVideo')
            }
          })
          .state('moreFeedback', {
            url:'/feedback',
            templateUrl: 'templates/more/more-feedback.html',
            controller: 'moreFeedbackCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/more/more-feedback')
            }
          })
          .state('moreAbout', {
            url:'/about',
            templateUrl: 'templates/more/more-about.html',
            controller: 'moreAboutCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/more/more-about')
            }
          })
        //********************************** 个人信息 ********************************//
          .state('personal', {
            url:'/personal',
            templateUrl: 'templates/personal/personal-info.html',
            controller: 'personalInfoCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/personal/personal-info')
            }
          })
          .state('personalHead', {
            url:'/personalhead',
            templateUrl: 'templates/personal/personal-head.html',
            controller: 'personalHeadCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/personal/personal-head')
            }
          })
          .state('personalChangePsw', {
            url:'/personalchangepsw',
            templateUrl: 'templates/personal/personal-changePsw.html',
            controller: 'personalChangePswCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/personal/personal-changePsw')
            }
          })
          .state('personalChangeName', {
            url:'/personalchangename',
            templateUrl: 'templates/personal/personal-changeName.html',
            controller: 'personalChangeNameCtrl',
            resolve: {
              deps: app.loadControllerJs('./controllers/personal/personal-changeName')
            }
          })
      });
    return app;
  });
